@@ -1,8 +1,9 @@
 #!/bin/sh
 
-RELEASEDATE=20100728
+RELEASEDATE=20130203
+SVNREV=4711
 
-svn co -r \{$((${RELEASEDATE} + 1))\} \
+svn co -r ${SVNREV} \
 	https://sauerbraten.svn.sourceforge.net/svnroot/sauerbraten \
 	sauerbraten-data-0.0.${RELEASEDATE}
 
